pub enum ParallelPolicy {
RequireAll,
RequireOne,
RequireN(usize),
}Expand description
Policy for determining when a parallel node succeeds or fails.
Variants
RequireAll
Succeed when all children succeed, fail if any child fails.
RequireOne
Succeed when any child succeeds, fail when all children fail.
RequireN(usize)
Succeed when at least N children succeed.