Prelude module for convenient imports
Structs
- Behavior
Config - Root configuration for a behavior composition.
- Behavior
Executor - Executor for behavior trees with tick-based execution.
- Behavior
Loader - Loader for creating behavior trees from JSON configuration.
- Context
- Ensemble
Node - Ensemble node for multi-model fusion.
- Execution
Context - Execution context for behavior trees.
- Execution
Stats - Statistics about behavior execution.
- Move
Node - MoveNode - Executes a velocity command
- Node
Config - Configuration for a single node.
- Node
Reference - Reference to a behavior node that will be instantiated at runtime.
- Node
Registry - Registry for behavior node types.
- Parallel
Node - Executes all child behaviors concurrently (in parallel).
- Select
OrNode - Executes child behaviors until one succeeds or all fail.
- Sensor
Check Node - SensorCheckNode - Checks sensor state
- Sequence
Node - Executes child behaviors in sequence until one fails or all succeed.
- Subsumption
Layer - A layer in the subsumption architecture with a priority and behavior.
- Subsumption
Node - Subsumption node for priority-based layered control.
- Timer
Node - TimerNode - Waits for a specified duration
- Wander
Node - WanderNode - Generates random movement commands
- Weighted
Model - A weighted model in an ensemble.
Enums
- Composition
Config - Configuration for a composition node (sequence, selector, parallel, or leaf).
- Ensemble
Strategy - Strategy for combining results from multiple models.
- Node
Status - Status returned by behavior nodes after each tick.
- Parallel
Policy - Policy for determining when a parallel node succeeds or fails.
- Parallel
Policy Config - Policy configuration for parallel nodes.
Traits
- Behavior
Node - Core trait that all behavior nodes must implement.
- Behavior
Node Ext - Extension trait for BehaviorNode to provide convenient helpers.
Type Aliases
- Boxed
Behavior - Type alias for boxed behavior nodes.